# 1.skyctl使用方式

### 1.1skyctl的安装方式

1) 使用 pip install skyctl 安装skyctl 工具

2) 使用 python -m site 查询skyctl 的安装路径

   (例如：/home/zdcloud/miniconda3/envs/UCTool/lib/python3.7/site-packages)

3) 将skyctl 的安装路径加入环境变量，你需要在`~/.bashrc`或`~/.bash_profile`文件中添加相应的`export`命令。这样，每次登录时都会自动设置环境变量。你可以使用文本编辑器打开这些文件，并将上述`export`命令添加到文件的末尾，然后保存并关闭文件

   （例如：export PATH=/home/zdcloud/miniconda3/envs/UCTool/lib/python3.7/site-packages/yours_package:$PATH）。最后，重新启动终端或执行以下命令使更改生效：source ~/.bashrc 或 source ~/.bash_profile

### 1.2 skyctl的更新方式

使用指令：pip install --upgrade skyctl 

